@@ -4,24 +4,29 @@
 
 """Top-level package for AWS CFN Custom resource Resolve parser."""
 
-import re
-import json
 import base64
+import json
+import re
+
 from boto3.session import Session
 from botocore.exceptions import ClientError
 
-
 __author__ = """John Preston"""
 __email__ = "john@ews-network.net"
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 
 
-SECRET_REGEXP = re.compile(
-    r"^(?:{{)resolve:secretsmanager:"
-    r"(?P<secret>(?:arn:aws:secretsmanager:[a-z0-9-]+:\d{12}:secret:)?"
-    r"(?:[\S+][^:}]+)|[\S+][^:}]+)"
-    r"(?::((?:SecretString:)(?P<key>[a-zA-Z0-9-_.][^:}]+))"
-    r"(:(?P<stage>[A-Z]+))?)?(?:}})$"
+SECRET_ARN_REGEXP = re.compile(
+    r"(?:{{resolve:secretsmanager:)"
+    r"(?P<arn>arn:(?P<partition>aws(?:-[a-z]+)?):secretsmanager:(?P<region>[a-z0-9-]+):"
+    r"(?P<account_id>\d{12}):"
+    r"(?:secret:(?P<secret_id>[a-z0-9A-Z-_./]+)))"
+    r"(?P<extra>(?::SecretString:(?P<secret_key>[a-z0-9A-Z-_./]+))(?::(?P<version>[a-z0-9A-Z-]+)?)?)?(?:}})"
+)
+
+SECRET_NAME_REGEXP = re.compile(
+    r"(?:{{resolve:secretsmanager:)(?P<name>[a-z0-9A-Z-_./]+)"
+    r"(?P<extra>(?::SecretString:(?P<secret_key>[a-z0-9A-Z-_./]+))(?:(::)(?P<version>[a-z0-9A-Z-]+)?)?)?(?:}})"
 )
 
 
@@ -59,12 +64,26 @@ def parse_secret_resolve_string(resolve_str):
     :return: tuple of the secret, key and stage.
     :rtype: tuple
     """
-    parts = SECRET_REGEXP.match(resolve_str)
-    secret = parts.group("secret")
-    if not secret:
-        raise ValueError("Unable to find the secret name or ARN in", resolve_str)
-    key = parts.group("key")
-    stage = parts.group("stage")
+    secret = None
+    key = None
+    stage = None
+    if SECRET_ARN_REGEXP.match(resolve_str):
+        parts = SECRET_ARN_REGEXP.match(resolve_str)
+        secret = parts.group("arn")
+        if not secret:
+            raise ValueError("Unable to find the secret ARN in", resolve_str)
+        key = parts.group("secret_key")
+        stage = parts.group("version")
+    elif SECRET_NAME_REGEXP.match(resolve_str):
+        parts = SECRET_NAME_REGEXP.match(resolve_str)
+        secret = parts.group("name")
+    else:
+        raise ValueError(
+            "Unable to define secret ARN nor secret name from", resolve_str
+        )
+    if parts:
+        key = parts.group("secret_key")
+        stage = parts.group("version")
 
     return secret, key, stage
 
@@ -103,11 +122,7 @@ def retrieve_secret(secret, key=None, stage=None, client=None, session=None):
         elif key and not keypresent(key, res):
             raise KeyError(f"Secret {secret} does not have a key {key}")
         return res
-    except (
-        client.exceptions.ResourceNotFoundException,
-        client.exceptions.ResourceNotFoundException,
-    ) as error:
-        print(f"Failed to find or decrypt secret {secret}")
+    except client.exceptions as error:
         print(error)
         raise
     except ClientError as error:
